@@ -15,13 +15,15 @@
 // dependent on the actual system time.
 
 
-void setUp(void)
+void
+setUp()
 {
     ntpcal_set_timefunc(timefunc);
     settime(2000, 1, 1, 0, 0, 0);
 }
 
-void tearDown(void)
+void
+tearDown()
 {
     ntpcal_set_timefunc(NULL);
 }
@@ -29,7 +31,8 @@ void tearDown(void)
 // ---------------------------------------------------------------------
 // test cases
 
-void test_CurrentYear(void) {
+void
+test_CurrentYear(void) {
 	// Timestamp: 2010-06-24 12:50:00Z
 	const u_int32 timestamp = 3486372600UL;
 	const u_int32 expected	= timestamp; // exactly the same.
@@ -44,7 +47,8 @@ void test_CurrentYear(void) {
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
-void test_CurrentYearFuzz(void) {
+void
+test_CurrentYearFuzz(void) {
 	/* 
 	 * Timestamp (rec_ui) is: 2010-06-24 12:50:00
 	 * Time sent into function is 12:00:00.
@@ -66,7 +70,8 @@ void test_CurrentYearFuzz(void) {
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
-void test_TimeZoneOffset(void) {
+void
+test_TimeZoneOffset(void) {
 	/*
 	 * Timestamp (rec_ui) is: 2010-06-24 12:00:00 +0800
 	 * (which is 2010-06-24 04:00:00Z)
@@ -86,7 +91,8 @@ void test_TimeZoneOffset(void) {
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
-void test_WrongYearStart(void) {
+void
+test_WrongYearStart(void) {
 	/* 
 	 * Timestamp (rec_ui) is: 2010-01-02 11:00:00Z
 	 * Time sent into function is 11:00:00.
@@ -105,7 +111,8 @@ void test_WrongYearStart(void) {
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
-void test_PreviousYear(void) {
+void
+test_PreviousYear(void) {
 	/*
 	 * Timestamp is: 2010-01-01 01:00:00Z
 	 * Time sent into function is 23:00:00
@@ -124,7 +131,8 @@ void test_PreviousYear(void) {
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
-void test_NextYear(void) {
+void
+test_NextYear(void) {
 	/*
 	 * Timestamp is: 2009-12-31 23:00:00Z
 	 * Time sent into function is 01:00:00
@@ -142,7 +150,8 @@ void test_NextYear(void) {
 	TEST_ASSERT_EQUAL(expected, actual);
 }
 
-void test_NoReasonableConversion(void) {
+void
+test_NoReasonableConversion(void) {
 	/* Timestamp is: 2010-01-02 11:00:00Z */
 	const u_int32 timestamp = 3471418800UL;
 	
@@ -154,9 +163,9 @@ void test_NoReasonableConversion(void) {
 						   &yearstart, &actual));
 }
 
-// *** FUNCTION isLE, to simulate gtest's ASSERT_LE using Unity's TEST_ASSERT_TRUE
-//tehnically boolean
-int isLE(u_int32 diff,u_int32 actual){
+
+int // technically boolean
+isLE(u_int32 diff,u_int32 actual){
 	if(diff <= actual){
 		return TRUE;
 	}
@@ -164,7 +173,8 @@ int isLE(u_int32 diff,u_int32 actual){
 }
 
 
-void test_AlwaysInLimit(void) {
+void
+test_AlwaysInLimit(void) {
 	/* Timestamp is: 2010-01-02 11:00:00Z */
 	const u_int32 timestamp = 3471418800UL;
 	const u_short prime_incs[] = { 127, 151, 163, 179 };
@@ -192,8 +202,7 @@ void test_AlwaysInLimit(void) {
 					diff = actual - timestamp;
 					if (diff >= 0x80000000UL)
 						diff = ~diff + 1;
-					TEST_ASSERT_TRUE(isLE(diff, (183u * SECSPERDAY))); // adding new function to return TRUE if first number is less or equal the second
-					//TEST_ASSERT_LE(diff, (183u * SECSPERDAY));
+					TEST_ASSERT_TRUE(isLE(diff, (183u * SECSPERDAY)));
 				}
 			}
 		}
